@@ -340,14 +340,8 @@ MainWindow::MainWindow(QWidget* parent)
 void MainWindow::filterOperations()
 {
   Q_FOREACH(const PluginNamePair& p, plugins) {
-    if(p.first->applicable()) {
-      Q_FOREACH(QAction* action, p.first->actions()) {
-        action->setVisible(true);
-      }
-    } else {
-      Q_FOREACH(QAction* action, p.first->actions()) {
-        action->setVisible(false);
-      }
+    Q_FOREACH(QAction* action, p.first->actions()) {
+        action->setVisible( p.first->applicable(action) );
     }
   }
 
@@ -796,6 +790,7 @@ void MainWindow::open(QString filename)
     // collect all io_plugins and offer them to load if the file extension match one name filter
     // also collect all available plugin in case of a no extension match
     Q_FOREACH(Polyhedron_demo_io_plugin_interface* io_plugin, io_plugins) {
+      if ( !io_plugin->canLoad() ) continue;
       all_items << io_plugin->name();
       if ( file_matches_filter(io_plugin->nameFilters(), filename) )
         selected_items << io_plugin->name();
@@ -895,10 +890,18 @@ void MainWindow::selectSceneItem(int i)
 
 void MainWindow::showSelectedPoint(double x, double y, double z)
 {
-  information(QString("Selected point: (%1, %2, %3)").
+  static double x_prev = 0;
+  static double y_prev = 0;
+  static double z_prev = 0;
+  double dist = std::sqrt((x-x_prev)*(x-x_prev) + (y-y_prev)*(y-y_prev) + (z-z_prev)*(z-z_prev)); 
+  information(QString("Selected point: (%1, %2, %3) distance to previous: %4").
               arg(x, 0, 'g', 10).
               arg(y, 0, 'g', 10).
-              arg(z, 0, 'g', 10));
+              arg(z, 0, 'g', 10).
+              arg(dist,0,'g',10));
+  x_prev = x;
+  y_prev = y;
+  z_prev = z;
 }
 
 void MainWindow::unSelectSceneItem(int i)
